@@ -42,7 +42,7 @@ class Tier(object):
     deploy_parser.add_argument("-d", "--no-djrestart", dest="djrestart", 
         default=True, action = "store_false", help="Dj Restart reqd: %s" %(self.tier))
     deploy_parser.add_argument("-s", "--srcpath", dest="src_path", 
-        default="~/src/", help="Root src directory %s")
+        default="~/src/", help="Root src directory")
     deploy_parser.set_defaults(func=self.deploy)
  
   def deploy(self, args):
@@ -83,12 +83,12 @@ class Tier(object):
     knife = Knife()
     output = ""
     if args.any:
-      output = knife.ssh_one(args.environment, self.tier, args.command)
+      output = knife.ssh_one(args.command, args.environment, self.tier)
     else:
-      output = knife.ssh(args.environment, self.tier, args.command)
+      output = knife.ssh(args.command, args.environment, self.tier)
     print output
   
   def screen(self, args):
     knife = Knife()
-    output = knife.ssh(args.environment, self.tier, "screen")
+    output = knife.ssh("screen", args.environment, self.tier)
     print output
